<?php
/**
 * The Header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="main">
 *
 * @package WordPress
 * @subpackage Blankfolio
 * @since Blankfolio 1.0
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>" />
<title><?php
	/*
	 * Print the <title> tag based on what is being viewed.
	 */
	global $page, $paged;

	wp_title( '|', true, 'right' );

	// Add the blog name.
	bloginfo( 'name' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		echo " | $site_description";

	// Add a page number if necessary:
	if ( $paged >= 2 || $page >= 2 )
		echo ' | ' . sprintf( __( 'Page %s', 'blankfolio' ), max( $paged, $page ) );

	?></title>
<link rel="profile" href="http://gmpg.org/xfn/11" />
<link rel="stylesheet" type="text/css" media="all" href="<?php bloginfo( 'stylesheet_url' ); ?>" />
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />


<!-- start bxSlider -->
<script src="http://code.jquery.com/jquery-latest.js" type="text/javascript"></script>
<script src="<?php bloginfo('template_directory'); ?>/js/jquery.bxSlider.min.js" type="text/javascript"></script>

<script type="text/javascript">
$(document).ready(function(){
  $('#slider').bxSlider({
	pager: false,
	mode: 'fade',
    auto: true,
	pause: 5000, // spacing in milliseconds 
    controls: false
  });
  });
</script>
<!-- end bxSlider -->

<?php
	/* We add some JavaScript to pages with the comment form
	 * to support sites with threaded comments (when in use).
	 */
	if ( is_singular() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	/* Always have wp_head() just before the closing </head>
	 * tag of your theme, or you will break many plugins, which
	 * generally use this hook to add elements to <head> such
	 * as styles, scripts, and meta tags.
	 */
	wp_head();
?>
</head>

<body <?php body_class(); ?>>

<div id="headerwrapper">	
<div id="header">
		<div id="logo">
					<?php if( get_option('of_logo') != '') { ?>
		<a class="image" href="<?php echo get_option('home'); ?>/" title="Home">
			<img src="<?php echo get_option('of_logo'); ?>"  />
		</a>
		<?php } else { ?>
			<h1 class="front-page-logo"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo('name'); ?></a></h1>	
			<h2><?php bloginfo('description'); ?></h2>
		<?php } ?>
		</div>
		
<div id="access">
		<?php wp_nav_menu( array( 'container_class' => 'menu-header', 'theme_location' => 'primary' ) ); ?>
</div><!-- end #access -->
</div><!-- end #header -->
</div><!-- end #headerwrapper -->		
	
	
<?php if (is_front_page()) : ?>			
	<div id="wrapper">
		<div id="sliderwrapper">
			<div id="slider">
				<?php $featuring = get_option('of_featured_category'); ?>
				<?php $featuredPosts = new WP_Query(); $featuredPosts->query('category_name='.$featuring.'&meta_key=_thumbnail_id&showposts='); ?>
				<?php while ($featuredPosts->have_posts()) : $featuredPosts->the_post(); ?>
					<div><a href="<?php the_permalink() ?>" rel="bookmark" title="Permanent Link to <?php the_title_attribute(); ?>"><?php the_post_thumbnail('featured'); ?></a></div>
				<?php endwhile; wp_reset_query(); ?>
			</div><!-- end #slider -->
			</div><!-- end #sliderwrapper -->
		</div><!-- end #wrapper -->
		
		<div id="welcome">

			<h2 class="welcome-title"><?php if( get_option('of_action') != '') { ?><?php echo get_option('of_action'); ?><?php } else { ?><?php the_title(); ?><?php } ?></h2>
			
			<div class="links">
		<a href="<?php echo get_option('of_viewmyworklink'); ?>">
			<?php if( get_option('of_viewmyworkbutton') != '') { ?>
				<img src="<?php echo get_option('of_viewmyworkbutton'); ?>"  class="buttonimage" />
			<?php } else { ?>
				<div class="button"><?php echo get_option('of_viewmyworktext'); ?></div>
			<?php } ?>
		</a>

		<a href="<?php echo get_option('of_moreaboutmelink'); ?>">
			<?php if( get_option('of_moreaboutmebutton') != '') { ?>
				<img src="<?php echo get_option('of_moreaboutmebutton'); ?>" class="buttonimage" />
			<?php } else { ?>
				<div class="button"><?php echo get_option('of_moreaboutmetext'); ?></div>
			<?php } ?>
		</a>

			</div><!-- end .links -->
		</div><!-- end #welcome -->
<?php endif; ?>	

<div id="container">
<div id="content-box">
